package com.fs.company.controller;

import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.domain.R;
import com.fs.common.core.page.TableDataInfo;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.company.domain.CompanySmsTemp;
import com.fs.company.service.ICompanySmsTempService;
import com.fs.company.vo.CompanySmsTempListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 短信模板Controller
 *
 * @author fs
 * @date 2023-01-09
 */
@RestController
@RequestMapping("/company/companySmsTemp")
public class CompanySmsTempController extends BaseController
{
    @Autowired
    private ICompanySmsTempService companySmsTempService;

    /**
     * 查询短信模板列表
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:list')")
    @GetMapping("/list")
    public TableDataInfo list(CompanySmsTemp companySmsTemp)
    {
        startPage();
        List<CompanySmsTempListVO> list = companySmsTempService.selectCompanySmsTempListVO(companySmsTemp);
        return getDataTable(list);
    }

    /**
     * 导出短信模板列表
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:export')")
    @Log(title = "短信模板", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CompanySmsTemp companySmsTemp)
    {
        List<CompanySmsTemp> list = companySmsTempService.selectCompanySmsTempList(companySmsTemp);
        ExcelUtil<CompanySmsTemp> util = new ExcelUtil<CompanySmsTemp>(CompanySmsTemp.class);
        return util.exportExcel(list, "companySmsTemp");
    }

    /**
     * 获取短信模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:query')")
    @GetMapping(value = "/{tempId}")
    public AjaxResult getInfo(@PathVariable("tempId") Long tempId)
    {
        return AjaxResult.success(companySmsTempService.selectCompanySmsTempById(tempId));
    }

    /**
     * 新增短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:add')")
    @Log(title = "短信模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CompanySmsTemp companySmsTemp)
    {
        return toAjax(companySmsTempService.insertCompanySmsTemp(companySmsTemp));
    }

    /**
     * 修改短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:edit')")
    @Log(title = "短信模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CompanySmsTemp companySmsTemp)
    {
        return toAjax(companySmsTempService.updateCompanySmsTemp(companySmsTemp));
    }

    /**
     * 删除短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:remove')")
    @Log(title = "短信模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{tempIds}")
    public AjaxResult remove(@PathVariable Long[] tempIds)
    {
        return toAjax(companySmsTempService.deleteCompanySmsTempByIds(tempIds));
    }


    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:audit')")
    @PostMapping("/audit")
    public R audit(@RequestBody CompanySmsTemp companySmsTemp)
    {
        CompanySmsTemp map=new CompanySmsTemp();
        map.setIsAudit(1);
        map.setTempId(companySmsTemp.getTempId());
        if(companySmsTempService.updateCompanySmsTemp(map)>0){
            return R.ok("操作成功");
        }
        else{
            return R.error("操作失败");
        }
    }
}
